# spotify-downloader-music-player

- A GUI version of [spotify-downloder](https://github.com/ritiek/spotify-downloader) of [Ritiek Malhotra](https://github.com/ritiek).
- It is one kind of mp3 music player which can download musics.
- It can download music from YouTube in MP3 format and can play them.
- It can download songs directly by typing name or typing the link.
- It can download the whole album by the link.

## Technologies
- python
- tkinter(GUI library) 

Tkinter is a Python binding to the Tk GUI toolkit. It is the standard Python interface to the Tk GUI toolkit, and is Python's de facto standard GUI. Tkinter is included with standard Linux, Microsoft Windows and Mac OS X installs of Python. The name Tkinter comes from Tk interface.

## Requirements installation
- `sudo apt install python3-tk`

## How to install the project into PC
- `pip3 install spotpl`
- `spotpl`

## Contributing
  Check out [CONTRIBUTING.md](https://github.com/rpotter12/spotify-downloader-music-player/blob/master/CONTRIBUTING.md) for more info.

## License 
  [MIT License](https://github.com/rpotter12/spotify-downloader-music-player/blob/master/LICENSE)

(If you like the project, support us by staring the project)
